@@ -1,17 +1,15 @@
 from __future__ import annotations
 
 import operator
-from functools import partial
 from functools import reduce
 from typing import TYPE_CHECKING
 from typing import Any
 from typing import Callable
-from typing import Container
 from typing import Iterable
 from typing import Literal
 from typing import Sequence
-from typing import cast
 
+from narwhals._compliant import CompliantNamespace
 from narwhals._expression_parsing import combine_alias_output_names
 from narwhals._expression_parsing import combine_evaluate_output_names
 from narwhals._spark_like.dataframe import SparkLikeLazyFrame
@@ -19,14 +17,9 @@ from narwhals._spark_like.expr import SparkLikeExpr
 from narwhals._spark_like.selectors import SparkLikeSelectorNamespace
 from narwhals._spark_like.utils import maybe_evaluate_expr
 from narwhals._spark_like.utils import narwhals_to_native_dtype
-from narwhals.typing import CompliantNamespace
-from narwhals.utils import exclude_column_names
-from narwhals.utils import get_column_names
-from narwhals.utils import passthrough_column_names
 
 if TYPE_CHECKING:
-    from pyspark.sql import Column
-    from pyspark.sql import DataFrame
+    from sqlframe.base.column import Column
     from typing_extensions import Self
 
     from narwhals.dtypes import DType
@@ -34,7 +27,7 @@ if TYPE_CHECKING:
     from narwhals.utils import Version
 
 
-class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  # type: ignore[type-var] # (#2044)
+class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "SparkLikeExpr"]):
     def __init__(
         self: Self,
         *,
@@ -50,40 +43,9 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
     def selectors(self: Self) -> SparkLikeSelectorNamespace:
         return SparkLikeSelectorNamespace(self)
 
-    def all(self: Self) -> SparkLikeExpr:
-        return SparkLikeExpr.from_column_names(
-            get_column_names,
-            function_name="all",
-            implementation=self._implementation,
-            backend_version=self._backend_version,
-            version=self._version,
-        )
-
-    def col(self: Self, *column_names: str) -> SparkLikeExpr:
-        return SparkLikeExpr.from_column_names(
-            passthrough_column_names(column_names),
-            function_name="col",
-            implementation=self._implementation,
-            backend_version=self._backend_version,
-            version=self._version,
-        )
-
-    def exclude(self: Self, excluded_names: Container[str]) -> SparkLikeExpr:
-        return SparkLikeExpr.from_column_names(
-            partial(exclude_column_names, names=excluded_names),
-            function_name="exclude",
-            implementation=self._implementation,
-            backend_version=self._backend_version,
-            version=self._version,
-        )
-
-    def nth(self: Self, *column_indices: int) -> SparkLikeExpr:
-        return SparkLikeExpr.from_column_indices(
-            *column_indices,
-            backend_version=self._backend_version,
-            version=self._version,
-            implementation=self._implementation,
-        )
+    @property
+    def _expr(self) -> type[SparkLikeExpr]:
+        return SparkLikeExpr
 
     def lit(self: Self, value: object, dtype: DType | None) -> SparkLikeExpr:
         def _lit(df: SparkLikeLazyFrame) -> list[Column]:
@@ -96,7 +58,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
 
             return [column]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=_lit,
             function_name="lit",
             evaluate_output_names=lambda _df: ["literal"],
@@ -110,7 +72,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
         def func(df: SparkLikeLazyFrame) -> list[Column]:
             return [df._F.count("*")]
 
-        return SparkLikeExpr(
+        return self._expr(
             func,
             function_name="len",
             evaluate_output_names=lambda _df: ["len"],
@@ -125,7 +87,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
             cols = (c for _expr in exprs for c in _expr(df))
             return [reduce(operator.and_, cols)]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="all_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -140,7 +102,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
             cols = (c for _expr in exprs for c in _expr(df))
             return [reduce(operator.or_, cols)]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="any_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -157,7 +119,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
             )
             return [reduce(operator.add, cols)]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="sum_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -186,7 +148,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
                 )
             ]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="mean_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -201,7 +163,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
             cols = (c for _expr in exprs for c in _expr(df))
             return [df._F.greatest(*cols)]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="max_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -216,7 +178,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
             cols = (c for _expr in exprs for c in _expr(df))
             return [df._F.least(*cols)]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="min_horizontal",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
@@ -232,7 +194,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
         *,
         how: Literal["horizontal", "vertical", "diagonal"],
     ) -> SparkLikeLazyFrame:
-        dfs = cast("Sequence[DataFrame]", [item._native_frame for item in items])
+        dfs = [item._native_frame for item in items]
         if how == "horizontal":
             msg = (
                 "Horizontal concatenation is not supported for LazyFrame backed by "
@@ -311,7 +273,7 @@ class SparkLikeNamespace(CompliantNamespace["SparkLikeLazyFrame", "Column"]):  #
 
             return [result]
 
-        return SparkLikeExpr(
+        return self._expr(
             call=func,
             function_name="concat_str",
             evaluate_output_names=combine_evaluate_output_names(*exprs),
