@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from importlib import import_module
 from typing import TYPE_CHECKING
 from typing import Any
 
@@ -11,9 +12,9 @@ from narwhals.utils import isinstance_or_issubclass
 if TYPE_CHECKING:
     from types import ModuleType
 
-    import pyspark.sql.types as pyspark_types
+    import sqlframe.base.functions as sqlframe_functions
     import sqlframe.base.types as sqlframe_types
-    from pyspark.sql import Column
+    from sqlframe.base.column import Column
     from typing_extensions import TypeAlias
 
     from narwhals._spark_like.dataframe import SparkLikeLazyFrame
@@ -21,7 +22,7 @@ if TYPE_CHECKING:
     from narwhals.dtypes import DType
     from narwhals.utils import Version
 
-    _NativeDType: TypeAlias = "pyspark_types.DataType | sqlframe_types.DataType"
+    _NativeDType: TypeAlias = sqlframe_types.DataType
 
 
 # NOTE: don't lru_cache this as `ModuleType` isn't hashable
@@ -30,7 +31,7 @@ def native_to_narwhals_dtype(
 ) -> DType:  # pragma: no cover
     dtypes = import_dtypes_module(version=version)
     if TYPE_CHECKING:
-        native = pyspark_types
+        native = sqlframe_types
     else:
         native = spark_types
 
@@ -83,10 +84,10 @@ def native_to_narwhals_dtype(
 
 def narwhals_to_native_dtype(
     dtype: DType | type[DType], version: Version, spark_types: ModuleType
-) -> pyspark_types.DataType:
+) -> _NativeDType:
     dtypes = import_dtypes_module(version)
     if TYPE_CHECKING:
-        native = pyspark_types
+        native = sqlframe_types
     else:
         native = spark_types
 
@@ -144,9 +145,10 @@ def narwhals_to_native_dtype(
             dtypes.UInt8,
             dtypes.Enum,
             dtypes.Categorical,
+            dtypes.Time,
         ),
     ):  # pragma: no cover
-        msg = "Unsigned integer, Enum and Categorical types are not supported by spark-like backend"
+        msg = "Unsigned integer, Enum, Categorical and Time types are not supported by spark-like backend"
         raise UnsupportedDTypeError(msg)
 
     msg = f"Unknown dtype: {dtype}"  # pragma: no cover
@@ -184,46 +186,79 @@ def maybe_evaluate_expr(df: SparkLikeLazyFrame, obj: SparkLikeExpr | object) ->
 
 
 def _std(
-    _input: Column | str,
+    column: Column,
     ddof: int,
     np_version: tuple[int, ...],
-    functions: Any,
+    functions: ModuleType,
     implementation: Implementation,
 ) -> Column:
-    if implementation is Implementation.SQLFRAME or np_version > (2, 0):
-        if ddof == 0:
-            return functions.stddev_pop(_input)
-        if ddof == 1:
-            return functions.stddev_samp(_input)
+    if TYPE_CHECKING:
+        F = sqlframe_functions  # noqa: N806
+    else:
+        F = functions  # noqa: N806
+    if implementation is Implementation.PYSPARK and np_version < (2, 0):
+        from pyspark.pandas.spark.functions import stddev
 
-        n_rows = functions.count(_input)
-        return functions.stddev_samp(_input) * functions.sqrt(
-            (n_rows - 1) / (n_rows - ddof)
-        )
-
-    from pyspark.pandas.spark.functions import stddev
-
-    input_col = functions.col(_input) if isinstance(_input, str) else _input
-    return stddev(input_col, ddof=ddof)
+        return stddev(column, ddof)  # pyright: ignore[reportReturnType, reportArgumentType]
+    if ddof == 0:
+        return F.stddev_pop(column)
+    if ddof == 1:
+        return F.stddev_samp(column)
+    n_rows = F.count(column)
+    return F.stddev_samp(column) * F.sqrt((n_rows - 1) / (n_rows - ddof))
 
 
 def _var(
-    _input: Column | str,
+    column: Column,
     ddof: int,
     np_version: tuple[int, ...],
-    functions: Any,
+    functions: ModuleType,
     implementation: Implementation,
 ) -> Column:
-    if implementation is Implementation.SQLFRAME or np_version > (2, 0):
-        if ddof == 0:
-            return functions.var_pop(_input)
-        if ddof == 1:
-            return functions.var_samp(_input)
+    if TYPE_CHECKING:
+        F = sqlframe_functions  # noqa: N806
+    else:
+        F = functions  # noqa: N806
+    if implementation is Implementation.PYSPARK and np_version < (2, 0):
+        from pyspark.pandas.spark.functions import var
 
-        n_rows = functions.count(_input)
-        return functions.var_samp(_input) * (n_rows - 1) / (n_rows - ddof)
+        return var(column, ddof)  # pyright: ignore[reportReturnType, reportArgumentType]
+    if ddof == 0:
+        return F.var_pop(column)
+    if ddof == 1:
+        return F.var_samp(column)
 
-    from pyspark.pandas.spark.functions import var
+    n_rows = F.count(column)
+    return F.var_samp(column) * (n_rows - 1) / (n_rows - ddof)
 
-    input_col = functions.col(_input) if isinstance(_input, str) else _input
-    return var(input_col, ddof=ddof)
+
+def import_functions(implementation: Implementation, /) -> ModuleType:
+    if implementation is Implementation.PYSPARK:
+        from pyspark.sql import functions
+
+        return functions
+    from sqlframe.base.session import _BaseSession
+
+    return import_module(f"sqlframe.{_BaseSession().execution_dialect_name}.functions")
+
+
+def import_native_dtypes(implementation: Implementation, /) -> ModuleType:
+    if implementation is Implementation.PYSPARK:
+        from pyspark.sql import types
+
+        return types
+    from sqlframe.base.session import _BaseSession
+
+    return import_module(f"sqlframe.{_BaseSession().execution_dialect_name}.types")
+
+
+def import_window(implementation: Implementation, /) -> type[Any]:
+    if implementation is Implementation.PYSPARK:
+        from pyspark.sql import Window
+
+        return Window
+    from sqlframe.base.session import _BaseSession
+
+    return import_module(
+        f"sqlframe.{_BaseSession().execution_dialect_name}.window"
+    ).Window
